<?php

class Reference extends DataObject {
	static $db = array(
		'Title' => 'Text',
		'Description' => 'HTMLText',
		'URLSegment' => 'Varchar(255)'
	);
	
	static $has_one = array(
		'Designer' => 'Designer',
		'Reference_Picture' => 'Reference_Picture',
		'ReferenceType' => 'ReferenceType',
		'Region' => 'Region'
	);
	
	
	static $field_labels = array(
		'Reference_Picture' => 'Reference Picture',
		'Designer_ProfilePictureExtra' => 'Extra Profile Picture',
	);
	
	public function getFrontEndFields() {
		$fields = $this->scaffoldFormFields(
			array(
				'restrictFields' => array(
					'Title',
					'Description',
					'Reference_Picture',
					'ReferenceType',
					'Region'
				)
			)
		);
		return $fields;
	}
	
	static $default_sort = 'Created DESC';
	
	public function getCMSFields()
		{
			$f = parent::getCMSFields();
			$f->removeByName('Title');
			$f->removeByName('Description');
			$f->removeByName('URLSegment');
			$f->addFieldToTab("Root.Main", new TextField('Title', 'Title'), 'Reference_Picture');
			$f->addFieldToTab("Root.Main", new SimpleTinyMCEField('Description', 'Description'), 'Reference_Picture');
			
			return $f;
		}
	
	
	
	public function onBeforeWrite(){
		if($this->Title){
			$this->URLSegment = SiteTree::GenerateURLSegment($this->Title);
			if($object = DataObject::get_one($this->ClassName, "URLSegment='".$this->URLSegment."' AND ID !=".$this->ID)){
				$this->URLSegment = $this->URLSegment.'-'.$this->ID;
			}
		} else {
			$this->URLSegment = SiteTree::GenerateURLSegment($this->ClassName.'-'.$this->ID);
		}
		parent::onBeforeWrite();
	}
	
	public function onBeforeDelete() {
		$member = Member::currentUser();
		$Link = "designers/Designer/" . $member->ID . "/view/";
		Director::redirect(Director::baseURL() . $Link);
		return parent::onBeforeDelete();
	}
	
	public function canView($member = null) {
		return true;
	}

	public function canCreate($member = null) {
		return true;
	}

	public function canEdit($member = null) {
		if(!$member) $member = Member::currentUser();
		if(!$member) return false;

		return (
			Permission::checkMember(
				$member, 
				'EDIT_ALL_REFERENCES'
			)
			|| $member->ID == $this->DesignerID
		);
	}

	public function canDelete($member = null) {
		if(!$member) $member = Member::currentUser();
		if(!$member) return false;

		return (
			Permission::checkMember(
				$member, 
				'EDIT_ALL_REFERENCES'
			)
			|| $member->ID == $this->DesignerID
		);
	}

	public function providePermissions() {
		return array(
			'EDIT_ALL_REFERENCES' => 'Edit all references'
		);
	}
	
}


class Reference_Picture extends Image {
 
	function generateLarge($gd) {
		return $gd->resizeRatio(470, 271, true);
	}
	function generateSmallThumb($gd) {
		return $gd->resizeRatio(190, 84, true);
	}
	function generateSmallThumbBW($gd) {
		return $gd->resizeRatio(190, 84, true)->greyscale();
	}
}

?>